@@ -55,18 +55,17 @@ class BinoutData(object):
         """
         return self._time_interp
 
-    def get_channels_ids_object_name(self, object_name, binout_data_type):
+    def get_channel_ids_from_object_name(self, object_name):
         """
 
         Args:
           object_name: type object_name:
-          binout_data_type: type plugin_name:
 
         Returns:
           np.array: time
 
         """
-        defined_ids = self._dynasaur_definitions.get_ids_from_name(object_name, self._name, binout_data_type)
+        defined_ids = self._dynasaur_definitions.get_object_ids_from_object_name(object_name, self._name)
         available_ids = self.get_ids()
         channel_ids = np.intersect1d(defined_ids, available_ids)
 
@@ -81,7 +80,7 @@ class BinoutData(object):
           np.array: ids as numpy array (np.uint32)
 
         """
-        return self._ids.astype(np.uint32)
+        return self._ids # .astype(np.uint32)
 
     def _interp_time(self, time_):
         """method to interpolate the given time to decimal values
@@ -402,7 +401,7 @@ class BinoutData(object):
           data array between data offset and date delta t
 
         """
-        ids = self.get_channels_ids_object_name(ID, self._name)
+        ids = self.get_channel_ids_from_object_name(object_name=ID)
 
         if len(ids) == 0:
             self._logger.emit(LOGConstants.ERROR[0], "Missing ID in binary input data, identifier: " + ID)
@@ -492,6 +491,9 @@ class BinoutData(object):
         elif "displacement" in channel_name:
             return l
 
+        elif "ring_slip" in channel_name:
+            return l
+
         elif "position" in channel_name:
             return l
 
