@@ -1,7 +1,8 @@
 import h5py
 import numpy as np
 
-from ..utils.constants import DataChannelTypesNodout, DataChannelTypesContact, DataChannelTypesSbtout
+from ..utils.constants import DataChannelTypesNodout, DataChannelTypesContact, DataChannelTypesSbtout, \
+    DataChannelTypesSecforc
 from ..utils.logger import ConsoleLogger
 from ..data.dynasaur_definitions import DynasaurDefinitions
 import re
@@ -29,7 +30,7 @@ class MadymoData:
             else:
                 assert False
 
-    def _extratct_data(self, node, data_type, channel_type, idx_madymo_data):
+    def _extratct_data(self, node, data_type, channel_type, idx_madymo_data, ids_name=None):
         """
 
         Args:
@@ -40,12 +41,13 @@ class MadymoData:
 
         Returns:
 
+
         """
-        ids_name = "ids" if data_type != "sbtout" else "belt_ids"
+        ids_name = ids_name if ids_name is not None else "ids"
         for idx, id_ in enumerate(self._d[data_type][ids_name]):
             keys = [i for i in node.keys() if i.startswith("SIGNAL")]
             for key in keys:
-                if data_type == "rcforc" or data_type == "sbtout":
+                if data_type == "rcforc" or data_type == "secforc":
                     id_string = ''.join([chr(i) for i in list(node[key].attrs.items())[0][1] if i != 0])
                     id_to_compare = self._get_simplified_double_id(id_string)
                 else:
@@ -183,7 +185,7 @@ class MadymoData:
 
         return simiplified_id, direction[0]
 
-    def _add_ids(self, node, data_type):
+    def _add_ids(self, node, data_type, sbtout=None):
         """add signal ids
 
         Args:
@@ -196,14 +198,19 @@ class MadymoData:
         signals = [signal for signal in node.keys() if signal.startswith("SIGNAL")]
         for signal in signals:
             id_string = ''.join([chr(i) for i in list(node[signal].attrs.items())[0][1] if i != 0]).strip()
-            if data_type == "rcforc" or data_type == "sbtout":
+            if data_type == "rcforc" or data_type == "secforc":
                 simplified_id = self._get_simplified_double_id(id_string)
             elif node.name.split("/")[-1] == "FEM node time-history output":
                 simplified_id, _ = self._get_simplified_fem_node_id(id_string)
             else:
                 simplified_id = id_string.split(" ")[0]
 
-            ids_name = "ids" if data_type != "sbtout" else "belt_ids"
+            ids_name = "ids"
+            if sbtout is "slipring":
+                ids_name = "slipring_ids"
+            if sbtout is "belt":
+                ids_name = "belt_ids"
+
             # assert (simiplified_id not in self._d[data_type][ids_name])
             # if assert: ID is already in id list
             if simplified_id in self._d[data_type][ids_name]:
@@ -287,8 +294,6 @@ class MadymoData:
                             1 if data_type == DataChannelTypesNodout.RY_DISPLACEMENT else 2)
                         self._extratct_data(f["MODEL_0/Angular displacements"], "nodout", data_type,
                                             idx_madymo_data=idx_madymo_data)
-                        self._extratct_data(f["/MODEL_0/Relative displacements"], "nodout", data_type,
-                                            idx_madymo_data=idx_madymo_data)
 
                     elif data_type == DataChannelTypesNodout.RX_VELOCITY or \
                             data_type == DataChannelTypesNodout.RY_VELOCITY or \
@@ -337,6 +342,10 @@ class MadymoData:
                             2 if data_type == DataChannelTypesNodout.Y_DISPLACEMENT else 3)
                         self._extratct_data(f["MODEL_0/Linear displacements"], "nodout", data_type,
                                             idx_madymo_data=idx_madymo_data)
+                        #self._extratct_data(f["/MODEL_0/Relative displacements"], "nodout", data_type,
+                        #                    idx_madymo_data=idx_madymo_data)
+                        #self._extratct_data(f["/MODEL_0/Retractor | pretensioner | load limiter | tying"], "nodout", data_type,
+                        #                    idx_madymo_data=idx_madymo_data)
 
                 if "FEM node time-history output" in f["MODEL_0"].keys():
                     self._extract_fem_node_data(f["MODEL_0/FEM node time-history output"], "nodout")
@@ -358,19 +367,39 @@ class MadymoData:
                     self._extract_data_energy(f["MODEL_0/Energy output"], 'glstat', self._d["glstat"]["ids"], energy_type)
                     self._d["glstat"][energy_type] = self._d["glstat"][energy_type].flatten()
 
+            if "secforc" in self._d:
+                dimension = (self._d['secforc']['time'].shape[0], len(self._d['secforc']['ids']))
+                data_types_to_be_filled = [i for i in self._d['secforc'].keys() if
+                                           i != "ids" and i != "time" and i != "legend_ids"]
+                for data_type in data_types_to_be_filled:
+                    self._d['secforc'][data_type] = np.empty(dimension)
+                    self._d['secforc'][data_type][:] = np.nan
+                    # TODO
+                    idx_madymo_data = 0 if data_type == DataChannelTypesSecforc.TOTAL_FORCE else \
+                    (1 if data_type == DataChannelTypesSecforc.X_FORCE else
+                     (2 if data_type == DataChannelTypesSecforc.Y_FORCE else 3))
+                    self._extratct_data(f["MODEL_0/Belt and restraint forces"], "secforc", data_type,
+                                        idx_madymo_data=idx_madymo_data)
+
             if "sbtout" in self._d:
-                dimension = (self._d['sbtout']['time'].shape[0], len(self._d['sbtout']['belt_ids']))
-                data_types_to_be_filled = [i for i in self._d['sbtout'].keys() if
-                                           i != "belt_ids" and i != "time" and i != "legend_ids"]
+
+                dimension = (self._d['sbtout']['time'].shape[0], len(self._d['sbtout']['slipring_ids']))
+                data_types_to_be_filled = ["ring_slip"]
+                print(data_types_to_be_filled)
                 for data_type in data_types_to_be_filled:
                     self._d['sbtout'][data_type] = np.empty(dimension)
                     self._d['sbtout'][data_type][:] = np.nan
-                    if data_type == DataChannelTypesSbtout.BELT_FORCE:
-                        self._extratct_data(f["MODEL_0/Belt and restraint forces"], "sbtout", data_type,
-                                    idx_madymo_data=0)
-                    elif data_type == DataChannelTypesSbtout.BELT_LENGTH:
-                        self._extratct_data(f["/MODEL_0/Retractor | pretensioner | load limiter | tying"],
-                                            "sbtout", data_type, idx_madymo_data=0)
+                    self._extratct_data(f["MODEL_0/Relative displacements"], "sbtout", data_type, idx_madymo_data=0,
+                                        ids_name="slipring_ids")
+                # TODO
+
+
+                dimension = (self._d['sbtout']['time'].shape[0], len(self._d['sbtout']['belt_ids']))
+                data_types_to_be_filled = ["belt_force", "belt_length"]# i for i in self._d['sbtout'].keys() if i != "ids" and i != "time" and i != "legend_ids"]
+                print(data_types_to_be_filled)
+                # TODO
+
+
         logger = ConsoleLogger()
         self.dynasaur_definitions = DynasaurDefinitions(logger)
 
@@ -430,27 +459,31 @@ class MadymoData:
                 if 'nodout' not in self._d.keys():
                     if node.parent.name.split("/")[-1].startswith("Angular ") or \
                             node.parent.name.split("/")[-1].startswith("Linear ") or \
-                            node.parent.name.split("/")[-1].startswith("Relative displacements"):
+                            node.parent.name.split("/")[-1].startswith():
                         self._d['nodout'] = {"ids": [], "legend_ids": [], "time": None}
 
                 if 'glstat' not in self._d.keys():
                     if node.parent.name.split("/")[-1].startswith("Energy output"):
-                        self._d['glstat'] = {"ids": [], "legend_ids":[], "time": None}
+                        self._d['glstat'] = {"ids": [], "legend_ids": [], "time": None}
 
                 if 'matsum' not in self._d.keys():
                     if node.parent.name.split("/")[-1].startswith("Energy output"):
-                        self._d['matsum'] = {"ids": [], "legend_ids":[], "time": None}
+                        self._d['matsum'] = {"ids": [], "legend_ids": [], "time": None}
 
                 if 'rcforc' not in self._d.keys():
-                    if node.parent.name.split("/")[-1].startswith("contact loads")  or \
+                    if node.parent.name.split("/")[-1].startswith("contact loads") or \
                             node.parent.name.split("/")[-1].startswith("Contact Penetration|Area"):
-                        self._d['rcforc'] = {"ids": [], "legend_ids":[], "time": None}
+                        self._d['rcforc'] = {"ids": [], "legend_ids": [], "time": None}
+
+                if 'secforc' not in self._d.keys():
+                    if node.parent.name.split("/")[-1].startswith("Belt and restraint forces") or \
+                            node.parent.name.split("/")[-1].startswith("Cross section forces"):
+                        self._d['secforc'] = {"ids": [], "legend_ids": [], "time": None}
 
                 if 'sbtout' not in self._d.keys():
-                    if node.parent.name.split("/")[-1].startswith("Belt ") or \
-                            node.parent.name.split("/")[-1].startswith("Retractor"):
-                        self._d['sbtout'] = {"belt_ids": [], "legend_ids":[], "time": None}
-                print(name)
+                    if node.parent.name.split("/")[-1].startswith("Relative displacements"):
+                        self._d['sbtout'] = {"belt_ids": [], "slipring_ids": [], "legend_ids": [], "time": None}
+
                 if node.parent.name.split("/")[-1].startswith("Energy output"):
                     # TODO
                     # self._d['glstat'][DataChannelTypesNodout.RX_ACCELERATION] = None
@@ -482,13 +515,6 @@ class MadymoData:
                     self._add_ids(node.parent, data_type="nodout")
                     self._add_time(node.parent, data_type="nodout")
 
-                elif node.parent.name.split("/")[-1].startswith("Relative displacements"):
-                    self._d['nodout'][DataChannelTypesNodout.RX_DISPLACEMENT] = None
-                    self._d['nodout'][DataChannelTypesNodout.RY_DISPLACEMENT] = None
-                    self._d['nodout'][DataChannelTypesNodout.RZ_DISPLACEMENT] = None
-                    self._add_ids(node.parent, data_type="nodout")
-                    self._add_time(node.parent, data_type="nodout")
-
                 elif node.parent.name.split("/")[-1].startswith("Linear accelerations"):
                     self._d['nodout'][DataChannelTypesNodout.X_ACCELERATION] = None
                     self._d['nodout'][DataChannelTypesNodout.Y_ACCELERATION] = None
@@ -530,14 +556,17 @@ class MadymoData:
                     self._add_ids(node.parent, data_type="rcforc")
                     self._add_time(node.parent, data_type="rcforc")
 
-                elif node.parent.name.split("/")[-1].startswith("Belt "):
-                    self._d['sbtout'][DataChannelTypesSbtout.BELT_FORCE] = None
-                    self._add_ids(node.parent, data_type="sbtout")
-                    self._add_time(node.parent, data_type="sbtout")
+                elif node.parent.name.split("/")[-1].startswith("Belt and restraint forces"):
+                    self._d['secforc'][DataChannelTypesSecforc.X_FORCE] = None
+                    self._d['secforc'][DataChannelTypesSecforc.Y_FORCE] = None
+                    self._d['secforc'][DataChannelTypesSecforc.Z_FORCE] = None
+                    self._d['secforc'][DataChannelTypesSecforc.TOTAL_FORCE] = None
+                    self._add_ids(node.parent, data_type="secforc")
+                    self._add_time(node.parent, data_type="secforc")
 
-                elif node.parent.name.split("/")[-1].startswith("Retractor "):
-                    self._d["sbtout"][DataChannelTypesSbtout.BELT_LENGTH] = None
-                    self._add_ids(node.parent, data_type="sbtout")
+                elif node.parent.name.split("/")[-1].startswith("Relative displacements"):
+                    self._d["sbtout"][DataChannelTypesSbtout.RING_SLIP] = None
+                    self._add_ids(node.parent, data_type="sbtout", sbtout="slipring")
                     self._add_time(node.parent, data_type="sbtout")
 
     def read(self, *argv):
