@@ -4,6 +4,7 @@ from ..utils.constants import LOGConstants, LoggerSCRIPT, IsommeConstants, Units
 
 
 class ISOMMEConverter:
+    """ """
     def __init__(self):
         self._unit_list = []
         self._transducer_type_list = []
@@ -19,6 +20,18 @@ class ISOMMEConverter:
         self._time_of_first_sample = ""
 
     def write_ISOMME(self, path_to_dir=None, data=None, dynasaur_definitions=None, logger=None, test=False):
+        """
+
+        Args:
+          path_to_dir:  (Default value = None)
+          data:  (Default value = None)
+          dynasaur_definitions:  (Default value = None)
+          logger:  (Default value = None)
+          test:  (Default value = False)
+
+        Returns:
+
+        """
         self._file_directory = path_to_dir
         if isinstance(self._file_directory, str) and self._file_directory == 'exit':
             return -1
@@ -104,6 +117,7 @@ class ISOMMEConverter:
         self.print_mme(test_nr_mme_dict)
 
     def get_channel_information_dict(self):
+        """ """
         channel_dict_list = []
 
         for i, channel_name in enumerate(self._channel_names):
@@ -127,6 +141,14 @@ class ISOMMEConverter:
         return channel_dict_list
 
     def get_channel_summary_dict(self, nr_of_channels):
+        """
+
+        Args:
+          nr_of_channels: 
+
+        Returns:
+
+        """
         channel_summary_dict = {"Instrumentation standard": IsommeConstants.INSTUMENTATION_STANDARD,
                                 "Number of channels": str(nr_of_channels)}
         for i, channel in enumerate(self._channel_names):
@@ -137,6 +159,7 @@ class ISOMMEConverter:
         return channel_summary_dict
 
     def get_test_nr_mme_dict(self):
+        """ """
         mme_dict = {"Data format edition number": "1.6", "Customer name": "Euro NCAP",
                     "Customer test ref number": "1", "Title": "Euro NCAP " + self._year_of_test,
                     "Type of the test": "Pedestrian", "Subtype of the test": "Certification",
@@ -147,6 +170,14 @@ class ISOMMEConverter:
         return mme_dict
 
     def get_channel_names(self, identifier_list):
+        """
+
+        Args:
+          identifier_list: 
+
+        Returns:
+
+        """
         channel_names = []
         for identifier in identifier_list:
             channel_name = ""
@@ -159,6 +190,14 @@ class ISOMMEConverter:
         return channel_names
 
     def get_unit_type_list(self, identifier_list):
+        """
+
+        Args:
+          identifier_list: 
+
+        Returns:
+
+        """
         unit_type_list = []
         for identifier in identifier_list:
             if identifier[0] == IsommeConstants.TIME:
@@ -186,6 +225,14 @@ class ISOMMEConverter:
         return unit_type_list
 
     def get_transducer_type(self, unit_list):
+        """
+
+        Args:
+          unit_list: 
+
+        Returns:
+
+        """
         transducer_type_list = []
         for unit in unit_list:
             if unit == UnitsConstants.MILLIMETER:
@@ -209,6 +256,14 @@ class ISOMMEConverter:
         return transducer_type_list
 
     def get_channel_codes(self, header_info):
+        """
+
+        Args:
+          header_info: 
+
+        Returns:
+
+        """
         channel_code = []
         if self._model_info == IsommeConstants.MODEL_6YO:
             for i, info in enumerate(header_info):
@@ -420,6 +475,14 @@ class ISOMMEConverter:
             return [IsommeConstants.NO_VALUE] * len(header_info)
 
     def print_channels(self, channel_dict_list):
+        """
+
+        Args:
+          channel_dict_list: 
+
+        Returns:
+
+        """
         for i, channel_dict in enumerate(channel_dict_list):
             channel_nr_string = str(i + 1)
             path = os.path.join(self._file_directory, self._test_nr, "Channel",
@@ -434,6 +497,14 @@ class ISOMMEConverter:
                     channel_file.write('{}\n'.format(value))
 
     def print_channel_summary(self, channel_summary_dict):
+        """
+
+        Args:
+          channel_summary_dict: 
+
+        Returns:
+
+        """
         path = os.path.join(self._file_directory, self._test_nr, "Channel", self._test_nr + ".chn")
         with open(path, 'w') as channel_summary_file:
             for key, value in channel_summary_dict.items():
@@ -443,6 +514,14 @@ class ISOMMEConverter:
                 channel_summary_file.write('{}\n'.format(row))
 
     def print_mme(self, mme_dict):
+        """
+
+        Args:
+          mme_dict: 
+
+        Returns:
+
+        """
         path = os.path.join(self._file_directory, self._test_nr, self._test_nr + ".mme")
         with open(path, 'w') as mme_file:
             for key, value in mme_dict.items():
@@ -452,6 +531,14 @@ class ISOMMEConverter:
                 mme_file.write('{}\n'.format(row))
 
     def create_output_directory(self, output_directory):
+        """
+
+        Args:
+          output_directory: 
+
+        Returns:
+
+        """
         if not os.path.exists(os.path.join(output_directory, self._test_nr)):
             os.mkdir(os.path.join(output_directory, self._test_nr))
         if not os.path.exists(os.path.join(output_directory, self._test_nr, "Channel")):
