@@ -211,8 +211,8 @@ class DataVisualizationController(PluginInterface, Plugin):
             self._data_dict.update({part_of: {}})
 
         if visualization not in self._data_dict[part_of].keys():
-            y_unit = y_data.units if isinstance(y_data, pint.Quantity) else "unknow"
-            x_unit = x_data.units if isinstance(x_data, pint.Quantity) else "unknow"
+            y_unit = y_data.units if isinstance(y_data, pint.Quantity) else "dimensionless"
+            x_unit = x_data.units if isinstance(x_data, pint.Quantity) else "dimensionless"
             x_data = x_data.magnitude if isinstance(x_data, pint.Quantity) else x_data
             y_data = y_data.magnitude if isinstance(y_data, pint.Quantity) else y_data
             self._data_dict[part_of].update({visualization: {"X": x_data,
